as.splits produces a list of splits or bipartitions.
as.splits(x, ...)
"as.splits"(x, ...)
"as.splits"(x, ...)
"print"(x, maxp = getOption("max.print"), zero.print = ".", one.print = "|", ...)
"as.prop.part"(x, ...)
compatible(obj)
allSplits(k, labels = NULL)
write.nexus.splits(obj, file = "", weights=NULL, taxa=TRUE, append=FALSE)
read.nexus.splits(file)
addTrivialSplits(obj)options(max.print), influences how many entries of large matrices are printed at all.as.splits returns an object of class splits, which is mainly a list of splits and some attributes.
Often a splits object will contain attributes confidences for bootstrap or Bayesian support values and
weight storing edge weights. read.nexus.splits and write.nexus.splits allow to exchange a
splits object with other software like Splitstree.compatible return a lower triangular matrix where an 1 indicates that two splits are incompatible.
prop.part, lento, distanceHadamard, as.networx
(sp <- as.splits(rtree(5)))
write.nexus.splits(sp)
Run the code above in your browser using DataLab