Learn R Programming

phangorn (version 2.0.4)

pml.fit: Internal maximum likelihood functions.

Description

These functions are internally used for the likelihood computations in pml or optim.pml.

Usage

pml.fit(tree, data, bf=rep(1/length(levels), length(levels)), shape=1, k=1, Q=rep(1, length(levels)*(length(levels)-1)/2), levels=attr(data, "levels"), inv=0, rate=1, g=NULL, w=NULL, eig=NULL, INV=NULL, ll.0=NULL, llMix=NULL, wMix=0, ..., site=FALSE) pml.init(data, k) pml.free() edQt(Q = c(1, 1, 1, 1, 1, 1), bf = c(0.25, 0.25, 0.25, 0.25)) lli(data, tree, ...) discrete.gamma(alpha, k)

Arguments

tree
A phylogenetic tree, object of class phylo.
data
An alignment, object of class phyDat.
bf
Base frequencies.
shape
Shape parameter of the gamma distribution.
alpha
Shape parameter of the gamma distribution.
k
Number of intervals of the discrete gamma distribution.
Q
A vector containing the lower triangular part of the rate matrix.
levels

inv
Proportion of invariable sites.
rate
Rate.
g

w

eig
Eigenvalue decomposition of Q
INV
Sparse representation of invariant sites
ll.0

llMix

wMix

...
Further arguments passed to or from other methods.
site

Value

pml.fit returns the log-likelihood.

Details

These functions are exported to be used in different packages so far only in the package coalescentMCMC, but are not intended for end user. Most of the functions call C code and are far less forgiving if the import is not what they expect than pml.

References

Felsenstein, J. (1981) Evolutionary trees from DNA sequences: a maximum likelihood approach. Journal of Molecular Evolution, 17, 368--376.

See Also

pml, pmlPart, pmlMix