splitsNetwork estimates a splits graph from a distance matrix.
Usage
splitsNetwork(dm, gamma=.1, lambda=0.001)
Arguments
dm
A distance matrix.
gamma
penalty value for the L1 constraint.
lambda
penalty value for the L2 constraint.
Value
splitsNetwork returns a matrix. The first column contains the
indices of the splits, the second column an unconstraint fit
without penalty terms and the third column the constraint fit.
Details
splitsNetwork fits phylogenetic networks using L1, L2 and
non-negativity constraints.
The function minimises the peanlised least squares
$$\beta = min \sum(dm - X\beta)^2 + \lambda \|\beta \|^2_2$$
with respect to $$\|\beta \|_1 <= \gamma,="" \beta="">= 0$$
where X is a design matrix constructed with designSplits.
External edges are fitted without constraints.=>