This function computes the Swofford--Olsen--Waddell--Hillis (SOWH) test, a parametric bootstrap test. The function is computational very demanding and likely to be very slow.
Usage
SOWH.test(x, n = 100, restricted = list(optNni=FALSE), optNni=TRUE, ...)
Arguments
x
an object of class "pml".
n
the number of bootstrap replicates.
restricted
list of restricted parameter settings.
optNni
Logical value indicating whether toplogy gets optimized (NNI).
...
Further arguments passed to "optim.pml".
Value
a numeric vector with the P-value associated with each tree given in
....
Details
SOWH.test performs a parametric bootstrap test to compare two trees.
It makes extensive use simSeq and optim.pml and can take quite long.
References
Goldman, N., Anderson, J. P., and Rodrigo, A. G. (2000) Likelihood
-based tests of topologies in phylogenetics. Systematic Biology49 652-670.
Swofford, D.L., Olsen, G.J., Waddell, P.J. and Hillis, D.M. (1996)
Phylogenetic Inference in Hillis, D.M., Moritz, C. and Mable, B.K. (Eds.)
Molecular Systematics (2nd ed.) 407-514, Sunderland, MA: Sinauer
# in real analysis use larger n, e.g. 100data(Laurasiatherian)
dm <- dist.logDet(Laurasiatherian)
tree <- NJ(dm)
fit <- pml(tree, Laurasiatherian)
res <- SOWH.test(fit, n=10)