bab finds all most parsimonious trees.bab(data, tree = NULL, trace = 1, ...)bab returns all most parsimonious trees in an object of class multiPhylo.bab is not like many other implementations restricted to binary or nucleotide data.pratchet, dfactorialdata(yeast)
dfactorial(11)
trees <- bab(yeast)Run the code above in your browser using DataLab