The complete list of functions can be displayed with library(help = phangorn).
Further information is available in several vignettes. To show the available
vignettes in an HTML browser type browseVignettes("phangorn").
Trees |
| Constructing phylogenetic trees (source, pdf) |
phangorn-specials |
| Advanced features (source, pdf) |
Ancestral |
| Ancestral sequence reconstruction (source, pdf) |
Networx |
| Splits and Networx (source, html) |
vignette('Trees')) gives an introduction in phylogenetic analysis with phangorn. The second vignette (phangorn-special) covers more advanced feature like defining special character spaces and things which fit nowhere else.
More information on phangorn can be found on http://www.phangorn.org.