treedist computes different tree distance methods and RF.dist the Robinson-Foulds distance.treedist(tree1, tree2)
RF.dist(tree1, tree2=NULL, check.labels=TRUE)phylo)
or vector of trees (an object of class multiPhylo). See detailstreedist returns a vector containing the following tree distance methodsmultiPhylo object is given.For large number of trees RF.dist can be slow and uses a lot of memory!
Using the fastmatch package and setting match <- fmatch can speed things up
further.